==> haskell-hi-file-parser-0.1.0.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hi-file-parser
version: 0.1.0.0
id: hi-file-parser-0.1.0.0-ikfZ0mH3FKCjNeirJXPZD
key: hi-file-parser-0.1.0.0-ikfZ0mH3FKCjNeirJXPZD
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Hussein Ait-Lahcen
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/stack/blob/master/subs/hi-file-parser/README.md>
category: Development
abi: c96be636e5075ae82a20f5635e3957b8
exposed: True
exposed-modules:
    HiFileParser
hidden-modules: Paths_hi_file_parser
import-dirs: /usr/lib/ghc-8.6.5/site-local/hi-file-parser-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hi-file-parser-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hi-file-parser-0.1.0.0
hs-libraries: HShi-file-parser-0.1.0.0-ikfZ0mH3FKCjNeirJXPZD
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock
haddock-html: /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hi-file-parser-0.1.0.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hi-file-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hi-file-parser
version: 0.1.0.0
id: hi-file-parser-0.1.0.0-9leXx6QESRqAHc4R5KXNQ3
key: hi-file-parser-0.1.0.0-9leXx6QESRqAHc4R5KXNQ3
license: BSD-3-Clause
maintainer: michael@snoyman.com
author: Hussein Ait-Lahcen
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Parser for GHC'\''s hi files
description:
    Please see the README on Github at <https://github.com/commercialhaskell/stack/blob/master/subs/hi-file-parser/README.md>
category: Development
abi: 0da971007fd2307ba3cabdea3fe36b7d
exposed: True
exposed-modules:
    HiFileParser
hidden-modules: Paths_hi_file_parser
import-dirs: /usr/lib/ghc-8.6.5/site-local/hi-file-parser-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hi-file-parser-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hi-file-parser-0.1.0.0
hs-libraries: HShi-file-parser-0.1.0.0-9leXx6QESRqAHc4R5KXNQ3
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    rio-0.1.12.0-FVrInZuoZCBFj7h6GfiM8d
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-hi-file-parser/html/hi-file-parser.haddock
haddock-html: /usr/share/doc/haskell-hi-file-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
